@@ -72,8 +72,6 @@ struct remote_dev_info {
 };
 
 struct hci_dev {
-	int ignore;
-
 	uint8_t  features[8];
 	uint8_t  extfeatures[8];
 	uint8_t  lmp_ver;
@@ -89,7 +87,7 @@ int adapter_start(struct btd_adapter *adapter);
 
 int adapter_stop(struct btd_adapter *adapter);
 
-int adapter_update(struct btd_adapter *adapter, uint8_t cls);
+int adapter_set_service_classes(struct btd_adapter *adapter, uint8_t value);
 
 int adapter_update_ssp_mode(struct btd_adapter *adapter, uint8_t mode);
 
@@ -177,6 +175,8 @@ int btd_adapter_restore_powered(struct btd_adapter *adapter);
 int btd_adapter_switch_online(struct btd_adapter *adapter);
 int btd_adapter_switch_offline(struct btd_adapter *adapter);
 
+typedef void (*bt_hci_result_t) (uint8_t status, gpointer user_data);
+
 struct btd_adapter_ops {
 	int (*setup) (void);
 	void (*cleanup) (void);
@@ -227,9 +227,11 @@ struct btd_adapter_ops {
 	int (*write_le_host) (int index, uint8_t le, uint8_t simul);
 	int (*get_remote_version) (int index, uint16_t handle,
 						gboolean delayed);
+	int (*encrypt_link) (int index, bdaddr_t *bdaddr, bt_hci_result_t cb,
+							gpointer user_data);
 };
 
-int btd_register_adapter_ops(struct btd_adapter_ops *btd_adapter_ops);
+int btd_register_adapter_ops(struct btd_adapter_ops *ops, gboolean priority);
 void btd_adapter_cleanup_ops(struct btd_adapter_ops *btd_adapter_ops);
 int adapter_ops_setup(void);
 
@@ -284,3 +286,6 @@ int btd_adapter_get_remote_name(struct btd_adapter *adapter,
 int btd_adapter_get_remote_version(struct btd_adapter *adapter,
 							uint16_t handle,
 							gboolean delayed);
+
+int btd_adapter_encrypt_link(struct btd_adapter *adapter, bdaddr_t *bdaddr,
+				bt_hci_result_t cb, gpointer user_data);
